@@ -1,6 +1,6 @@
 package Math::Vector::Real;
 
-our $VERSION = '0.14';
+our $VERSION = '0.17';
 
 use strict;
 use warnings;
@@ -224,16 +224,12 @@ sub abs {
     sqrt $acu;
 }
 
-*norm = \&abs;
-
 sub abs2 {
     my $acu = 0;
     $acu += $_ * $_ for @{$_[0]};
     $acu;
 }
 
-*norm2 = \&abs2;
-
 sub dist {
     &_check_dim;
     my ($v0, $v1) = @_;
@@ -256,6 +252,25 @@ sub dist2 {
     $d2;
 }
 
+sub max_component {
+    my $max = 0;
+    for (@{shift()}) {
+	my $abs = CORE::abs($_);
+	$abs > $max and $max = $abs;
+    }
+    $max
+}
+
+sub min_component {
+    my $self = shift; 
+    my $min = CORE::abs($self->[0]);
+    for (@$self) {
+	my $abs = CORE::abs($_);
+	$abs < $min and $min = $abs;
+    }
+    $min
+}
+
 sub manhattan_norm {
     my $n = 0;
     $n += CORE::abs($_) for @{$_[0]};
@@ -270,6 +285,17 @@ sub manhattan_dist {
     return $d;
 }
 
+sub chebyshev_dist {
+    &_check_dim;
+    my ($v0, $v1) = @_;
+    my $max = 0;
+    for (0..$#$v0) {
+        my $d = CORE::abs($v0->[$_] - $v1->[$_]);
+        $max = $d if $d > $max;
+    }
+    $max;
+}
+
 sub _upgrade {
     my $dim;
     map {
@@ -319,28 +345,6 @@ sub wrap {
 		  $c - $s * POSIX::floor($c/$s) } (0..$#$self)];
 }
 
-sub max_component {
-    my $max = 0;
-    for (@{shift()}) {
-	my $abs = CORE::abs($_);
-	$abs > $max and $max = $abs;
-    }
-    $max
-}
-
-sub min_component {
-    my $self = shift; 
-    my $min = CORE::abs($self->[0]);
-    for (@$self) {
-	my $abs = CORE::abs($_);
-	$abs < $min and $min = $abs;
-    }
-    $min
-}
-
-*max = \&max_component;
-*min = \&min_component;
-
 sub first_orthant_reflection {
     my $self = shift;
     bless [map CORE::abs, @$self];
@@ -456,6 +460,28 @@ sub max_dist2_to_box {
     return $d2;
 }
 
+sub dist2_between_boxes {
+    my ($class, $a0, $a1, $b0, $b1) = @_;
+    my ($c0, $c1) = $class->box($a0, $a1);
+    my ($d0, $d1) = $class->box($b0, $b1);
+    my $d2 = 0;
+    for (0..$#$c0) {
+        my $e0 = $d0->[$_] - $c1->[$_];
+        if ($e0 >= 0) {
+            $d2 += $e0 * $e0;
+        }
+        else {
+            my $e1 = $c0->[$_] - $d1->[$_];
+            if ($e1 > 0) {
+                $d2 += $e1 * $e1;
+            }
+        }
+    }
+    $d2;
+}
+
+*min_dist2_between_boxes = \&dist2_between_boxes;
+
 sub max_dist2_between_boxes {
     my ($class, $a0, $a1, $b0, $b1) = @_;
     my ($c0, $c1) = $class->box($a0, $a1);
@@ -605,6 +631,13 @@ sub select_in_ball_ref2bitmap {
     return $bm;
 }
 
+# This is run *after* Math::Vector::Real::XS is loaded!
+*norm = \&abs;
+*norm2 = \&abs2;
+*max = \&max_component;
+*min = \&min_component;
+*chebyshev_norm = \&max_component;
+
 1;
 __END__
 
@@ -769,6 +802,23 @@ Returns the distance between the two vectors.
 
 Returns the distance between the two vectors squared.
 
+=item $d = $v->manhattan_norm
+
+Returns the norm of the vector calculated using the Manhattan metric.
+
+=item $d = $v->manhattan_dist($u)
+
+Returns the distance between the two vectors using the Manhattan metric.
+
+=item $d = $v->chebyshev_norm
+
+Returns the norm of the vector calculated using the Chebyshev metric
+(note that this method is an alias for C<max_component>.
+
+=item $d = $v->chebyshev_dist
+
+Returns the distance between the two vectors using the Chebyshev metric.
+
 =item ($bottom, $top) = Math::Vector::Real->box($v0, $v1, $v2, ...)
 
 Returns the two corners of the L<axis-aligned minimum bounding
@@ -805,6 +855,12 @@ Calculates the square of the maximum distance between the vector C<$v>
 and the minimal axis-aligned box containing all the vectors C<($w0,
 $w1, ...)>.
 
+=item $d2 = Math::Vector::Real->dist2_between_boxes($a0, $a1, $b0, $b1)
+
+Returns the square of the minimum distance between any two points
+belonging to the boxes defined by C<($a0, $a1)> and
+C<($b0, $b1)> respectively.
+
 =item $d2 = Math::Vector::Real->max_dist2_between_boxes($a0, $a1, $b0, $b1)
 
 Returns the square of the maximum distance between any two points
@@ -941,7 +997,7 @@ wishlist: L<http://amzn.com/w/1WU1P6IR5QZ42>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2009-2012, 2014 by Salvador FandiE<ntilde>o
+Copyright (C) 2009-2012, 2014, 2015 by Salvador FandiE<ntilde>o
 (sfandino@yahoo.com)
 
 This library is free software; you can redistribute it and/or modify
